#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


# To be defined by user
%define build_flavor default
# variant includes dash: %%define variant -azure
%define variant %{nil}
%define subpackage base
%define extrasummary base modules
%define extradescription This package contains only the base modules, required in all installs.

%define misc_modules button edd i6300esb efivarfs qemu_fw_cfg hid-generic iscsi_ibft ptp_kvm

%define virtio_modules virtio virtio_.* virtio-.*

%define xen_modules xenblk xennet xen-.*

%define vmware_modules vmxnet3 vmw_.*

%define hyperv_modules hid-hyperv hv_balloon hv_utils \
hv_vmbus hyperv-keyboard hv_netvsc hv_storvsc scsi_transport_fc hyperv_fb

%define net_drivers 8390 ne2k-pci tulip e100 e1000 e1000e 8139cp 8139too dummy

%define scsi_modules scsi_transport_iscsi sd_mod sg sr_mod st scsi_mod

%define block_drivers loop dm-mod libata libahci ahci ata_piix mptsas mptspi \
        BusLogic sym53c8xx am53c974 rbd brd

%define usb_modules usb-common usbcore ehci-hcd ehci-pci ohci-hcd ohci-pci uhci-hcd \
xhci-hcd xhci-pci typec typec_ucsi ucsi_acpi typec ums-alauda ums-cypress ums-datafab \
ums-eneub6250 ums-freecom ums-isd200 ums-jumpshot ums-karma ums-onetouch \
ums-realtek ums-sddr09 ums-sddr55 ums-usbat usb-storage usbhid

%define filesystems autofs4 btrfs ext4 fuse vfat isofs jbd2 mbcache nfsv2 \
        nfsv3 nfsv4 overlay xfs nls_cp437 nls_iso8859-1 nls_utf8 ceph cifs squashfs nfsd \
        nfs_layout_.* quota_.* binfmt_misc exfat

%define networking \
af_packet arptable_filter arp_tables arpt_mangle bpfilter bridge br_netfilter    \
cls_bpf ebt_.* ebtable_.* ebtables ip6table_.* ip6_tables ip6t_.* ip_.* ipt_.* iptable_.* \
nf_.* nfnetlink.* nft_.* openvswitch sch_ingress tun veth xfrm.*_tunnel xfrm_.* \
x_tables xt_.* vport-.* vxlan vport-.* wireguard \
netlink_diag af_packet_diag raw_diag inet_diag tcp_diag udp_diag unix_diag vsock_diag

%define crypto_modules \
%(rpm -ql %{kernel_package_name} | grep -E 'kernel/crypto/|kernel/arch/.*/crypto/' | xargs basename -a | cut -d. -f1)

%define modules %usb_modules %net_drivers %scsi_modules %block_drivers \
                %hyperv_modules %virtio_modules %vmware_modules %xen_modules \
                %networking %filesystems %misc_modules %crypto_modules

# Reasonable defaults that might be overriden if needed
%define kernel_package_name kernel-%build_flavor
%define package_name %kernel_package_name-%subpackage
%define url %(rpm -q --qf '%%{URL}' %kernel_package_name)
%define group %(rpm -q --qf '%%{GROUP}' %kernel_package_name)
%define summary %(rpm -q --qf '%%{SUMMARY}' %kernel_package_name) - %extrasummary

Name:           %package_name
VCS: https://src.suse.de/SLFO-pool/kernel-default-base#801eb25aadc1515b5d5bab5391f3b84f7306464cc9c7f65ee62f29e11708a373
BuildRequires:  %kernel_package_name
BuildRequires:  %kernel_package_name-devel
BuildRequires:  coreutils
BuildRequires:  findutils
BuildRequires:  grep
BuildRequires:  kernel-subpackage-macros
Summary:        %summary
License:        GPL-2.0-only
Group:          %group
URL:            %url
# on SLE limit to architectures that actually have a kernel :-)
%if 0%{?sle_version}
ExclusiveArch:  aarch64 armv7hl ppc64le x86_64
%else
# does not boot on s390, s390 drivers are not included
ExcludeArch:    s390 s390x
%endif

# Internal stuff begins
%define rpm_kver %(rpm -q --qf '%%{VERSION}' %kernel_package_name)
%define rpm_krel %(rpm -q --qf '%%{RELEASE}' %kernel_package_name)
Version:        %rpm_kver
Release:        %rpm_krel.21.6

%define scriptdir /usr/lib/rpm/kernel
%include %scriptdir/kernel-subpackage-spec

%changelog
* Mon Oct 30 2023 fvogt@suse.com
- Add dummy (boo#1216647)
* Thu Jun  8 2023 gmoro@suse.com
- Add ptp_kvm (bsc#1211969)
* Mon Apr 24 2023 msuchanek@suse.com
- Do not build on s390 (bsc#1210729)
* Tue Mar 28 2023 fvogt@suse.com
- Add exfat (boo#1208822)
* Fri Oct  7 2022 fvogt@suse.com
- Add _diag modules for included socket types (boo#1204042)
* Wed Mar  2 2022 fvogt@suse.com
- Add binfmt_misc (boo#1196373)
* Tue Mar  1 2022 fvogt@suse.com
- Add quota modules (bsc#1196585)
- Add nfs layout modules
* Fri Oct  1 2021 fvogt@suse.com
- Add nls_utf8 module (boo#1190797)
* Wed Jun  2 2021 fvogt@suse.com
- Add nfsd for nfs server support (boo#1186363 bsc#1089118)
* Mon Feb 22 2021 fvogt@suse.com
- Add squashfs for kiwi installiso support (bsc#1182341)
* Mon Feb 22 2021 fvogt@suse.com
- Add fuse (boo#1182507)
* Thu Feb 11 2021 fvogt@suse.com
- Add modules which got lost when migrating away from supported.conf
  (bsc#1182110):
  * am53c974 had a typo
  * cls_bpf, iscsi_ibft, libahci, libata, openvswitch, sch_ingress
- Also add vport-* modules for Open vSwitch
* Thu Nov 26 2020 fvogt@suse.com
- Add wireguard (boo#1179225)
* Tue Oct 13 2020 fvogt@suse.com
- Create the list of crypto modules dynamically, supersedes hardcoded
  list of crc32 implementations (boo#1177577)
* Mon Oct  5 2020 fvogt@suse.com
- Add cifs
* Wed May 20 2020 fvogt@suse.com
- Add vxlan (bsc#1171903)
* Mon May 18 2020 msuchanek@suse.com
- Add usbhid and hid-generic for USB input devices (boo#1167749)
* Mon May  4 2020 fvogt@suse.com
- Add hardware-specific crc32c implementations (boo#1171065)
* Tue Apr 21 2020 msuchanek@suse.de
- Add qemu_fw_cfg needed by ignition (boo#1170069).
* Thu Feb 27 2020 fvogt@suse.com
- Add tcp_diag, needed by openslp
* Tue Feb 18 2020 fvogt@suse.com
- Add the brd module, used by the LTP testsuite and tiny
* Thu Jan  9 2020 gmoro@suse.com
- Remove iscsi_ibft (bsc#1157460)
* Fri Oct 25 2019 msuchanek@suse.com
- Add efivarfs required by mokutil (bsc#1154858).
* Mon Oct 14 2019 gmoro@suse.com
- Add Ceph modules (bsc#1149605)
* Thu Aug 15 2019 fvogt@suse.com
- Fix wildcard for ip6t_.*
* Thu Aug  8 2019 msuchanek@suse.de
- Shorten module list by using wildcards.
* Fri Jul 26 2019 fvogt@suse.com
- Add all netfilter and xfrm modules (boo#1142841)
* Thu Apr 11 2019 msuchanek@suse.de
- dw_mmc-bluefield is not needed in kernel-default-base (bsc#1131574).
* Thu Apr  4 2019 msuchanek@suse.de
- Add dw_mmc-bluefield driver (bsc#1118752)
* Thu Apr  4 2019 fvogt@suse.com
- Add back bpfilter, got lost during split (boo#1106751)
* Wed Mar 27 2019 lnussel@suse.de
- Limit build architectures on SLE to the ones that actually have a kernel in
  SLE (ie not i586).
* Fri Mar 15 2019 msuchanek@suse.de
- Separate kernel-deafult-base from kernel-default (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
